@@ -25,10 +25,11 @@ class Collection:
         self.__dict = dict()
 
     def __create(self, doc_id, doc):
+        doc_dict = doc if isinstance(doc, dict) else dict(doc.__dict__)
         data = {
             'secret': self.__api_key__,
             'collectionName': self.__collection_name__,
-            'doc': doc.__dict__,
+            'doc': doc_dict,
             'id': doc_id
         }
         response = requests.post(url, json=data)
